@@ -2,10 +2,13 @@ from braintree.add_on import AddOn
 from braintree.add_on_gateway import AddOnGateway
 from braintree.address import Address
 from braintree.address_gateway import AddressGateway
+from braintree.android_pay_card import AndroidPayCard
+from braintree.amex_express_checkout_card import AmexExpressCheckoutCard
 from braintree.apple_pay_card import ApplePayCard
 from braintree.braintree_gateway import BraintreeGateway
 from braintree.client_token import ClientToken
 from braintree.configuration import Configuration
+from braintree.credentials_parser import CredentialsParser
 from braintree.credit_card import CreditCard
 from braintree.credit_card_gateway import CreditCardGateway
 from braintree.credit_card_verification import CreditCardVerification
@@ -20,6 +23,7 @@ from braintree.error_codes import ErrorCodes
 from braintree.error_result import ErrorResult
 from braintree.errors import Errors
 from braintree.environment import Environment
+from braintree.merchant import Merchant
 from braintree.merchant_account import MerchantAccount
 from braintree.merchant_account.business_details import BusinessDetails
 from braintree.merchant_account.funding_details import FundingDetails
@@ -35,6 +39,7 @@ from braintree.plan import Plan
 from braintree.plan_gateway import PlanGateway
 from braintree.resource_collection import ResourceCollection
 from braintree.risk_data import RiskData
+from braintree.three_d_secure_info import ThreeDSecureInfo
 from braintree.search import Search
 from braintree.settlement_batch_summary import SettlementBatchSummary
 from braintree.subscription import Subscription
@@ -60,3 +65,4 @@ from braintree.webhook_notification_gateway import WebhookNotificationGateway
 from braintree.webhook_testing import WebhookTesting
 from braintree.webhook_testing_gateway import WebhookTestingGateway
 from braintree.europe_bank_account import EuropeBankAccount
+from braintree.venmo_account import VenmoAccount
