@@ -11,12 +11,12 @@ class CreditCardVerificationGateway(object):
 
     def find(self, verification_id):
         try:
-            if verification_id == None or verification_id.strip() == "":
+            if verification_id is None or verification_id.strip() == "":
                 raise NotFoundError()
-            response = self.config.http().get("/verifications/" + verification_id)
+            response = self.config.http().get(self.config.base_merchant_path() + "/verifications/" + verification_id)
             return CreditCardVerification(self.gateway, response["verification"])
         except NotFoundError:
-            raise NotFoundError("Verification with id " + verification_id + " not found")
+            raise NotFoundError("Verification with id " + repr(verification_id) + " not found")
 
     def __criteria(self, query):
         criteria = {}
@@ -30,7 +30,7 @@ class CreditCardVerificationGateway(object):
     def __fetch(self, query, ids):
         criteria = self.__criteria(query)
         criteria["ids"] = CreditCardVerificationSearch.ids.in_list(ids).to_param()
-        response = self.config.http().post("/verifications/advanced_search", {"search": criteria})
+        response = self.config.http().post(self.config.base_merchant_path() + "/verifications/advanced_search", {"search": criteria})
         return [CreditCardVerification(self.gateway, item) for item in
                 ResourceCollection._extract_as_array(response["credit_card_verifications"], "verification")]
 
@@ -39,11 +39,11 @@ class CreditCardVerificationGateway(object):
         if isinstance(query[0], list):
             query = query[0]
 
-        response = self.config.http().post("/verifications/advanced_search_ids", {"search": self.__criteria(query)})
+        response = self.config.http().post(self.config.base_merchant_path() + "/verifications/advanced_search_ids", {"search": self.__criteria(query)})
         return ResourceCollection(query, response, self.__fetch)
 
     def __fetch_verifications(self, query, verification_ids):
         criteria = {}
         criteria["ids"] = IdsSearch.ids.in_list(verification_ids).to_param()
-        response = self.config.http().post("/verifications/advanced_search", {"search": criteria})
+        response = self.config.http().post(self.config.base_merchant_path() + "/verifications/advanced_search", {"search": criteria})
         return [CreditCardVerification(self.gateway, item) for item in ResourceCollection._extract_as_array(response["credit_card_verifications"], "verification")]
