@@ -34,6 +34,7 @@ class ErrorCodes(object):
         PostalCodeIsTooLong = "81809"
         RegionIsInvalid = "91825"
         RegionIsTooLong = "81810"
+        StateIsInvalidForSellerProtection = "81827"
         StreetAddressIsInvalid = "91822"
         StreetAddressIsRequired = "81811"
         StreetAddressIsTooLong = "81812"
@@ -83,8 +84,10 @@ class ErrorCodes(object):
 
     class CreditCard(object):
         BillingAddressConflict = "91701"
+        BillingAddressFormatIsInvalid = "91744"
         BillingAddressIdIsInvalid = "91702"
         CannotUpdateCardUsingPaymentMethodNonce = "91735"
+        CannotUpdateCardUsingPaymentMethodNonce = "91735"
         CardholderNameIsTooLong = "81723"
         CreditCardTypeIsNotAccepted = "81703"
         CreditCardTypeIsNotAcceptedBySubscriptionMerchantAccount = "81718"
@@ -100,15 +103,21 @@ class ErrorCodes(object):
         ExpirationDateYearIsInvalid = "81711"
         ExpirationMonthIsInvalid = "81712"
         ExpirationYearIsInvalid = "81713"
+        InvalidParamsForCreditCardUpdate = "91745"
         InvalidVenmoSDKPaymentMethodCode = "91727"
         NumberHasInvalidLength = NumberLengthIsInvalid = "81716"
         NumberIsInvalid = "81715"
         NumberIsRequired = "81714"
         NumberMustBeTestNumber = "81717"
         PaymentMethodConflict = "81725"
+        PaymentMethodIsNotACreditCard = "91738"
+        PaymentMethodNonceCardTypeIsNotAccepted = "91734"
         PaymentMethodNonceCardTypeIsNotAccepted = "91734"
         PaymentMethodNonceConsumed = "91731"
+        PaymentMethodNonceConsumed = "91731"
         PaymentMethodNonceLocked = "91733"
+        PaymentMethodNonceLocked = "91733"
+        PaymentMethodNonceUnknown = "91732"
         PaymentMethodNonceUnknown = "91732"
         PostalCodeVerificationFailed = "81737"
         TokenInvalid = TokenFormatIsInvalid = "91718"
@@ -118,20 +127,16 @@ class ErrorCodes(object):
         TokenIsTooLong = "91720"
         VenmoSDKPaymentMethodCodeCardTypeIsNotAccepted = "91726"
         VerificationNotSupportedOnThisMerchantAccount = "91730"
-        PaymentMethodNonceConsumed = "91731"
-        PaymentMethodNonceUnknown = "91732"
-        PaymentMethodNonceLocked = "91733"
-        PaymentMethodNonceCardTypeIsNotAccepted = "91734"
-        PaymentMethodIsNotACreditCard = "91738"
-        CannotUpdateCardUsingPaymentMethodNonce = "91735"
 
         class Options(object):
             UpdateExistingTokenIsInvalid = "91723"
             UpdateExistingTokenNotAllowed = "91729"
-            VerificationMerchantAccountIdIsInvalid = "91728"
             VerificationAmountCannotBeNegative = "91739"
             VerificationAmountFormatIsInvalid = "91740"
             VerificationAmountNotSupportedByProcessor = "91741"
+            VerificationMerchantAccountIdIsInvalid = "91728"
+            VerificationMerchantAccountIsForbidden = "91743"
+            VerificationMerchantAccountIsSuspended = "91742"
 
 
     class Customer(object):
@@ -151,6 +156,7 @@ class ErrorCodes(object):
         IdIsTooLong = "91612"
         LastNameIsTooLong = "81613"
         PhoneIsTooLong = "81614"
+        VaultedPaymentInstrumentNonceBelongsToDifferentCustomer = "91617"
         WebsiteIsInvalid = WebsiteFormatIsInvalid = "81616"
         WebsiteIsTooLong = "81615"
 
@@ -162,6 +168,21 @@ class ErrorCodes(object):
         PhoneFormatIsInvalid = "92202"
         UrlFormatIsInvalid = "92206"
 
+    class Merchant(object):
+        CountryCannotBeBlank = "83603"
+        CountryCodeAlpha2IsInvalid = "93607"
+        CountryCodeAlpha2IsNotAccepted = "93606"
+        CountryCodeAlpha3IsInvalid = "93605"
+        CountryCodeAlpha3IsNotAccepted = "93604"
+        CountryCodeNumericIsInvalid = "93609"
+        CountryCodeNumericIsNotAccepted = "93608"
+        CountryNameIsInvalid = "93611"
+        CountryNameIsNotAccepted = "93610"
+        EmailFormatIsInvalid = "93602"
+        EmailIsRequired = "83601"
+        InconsistentCountry = "93612"
+        PaymentMethodsAreInvalid = "93613"
+
     class MerchantAccount(object):
         IdFormatIsInvalid = "82603"
         IdIsInUse = "82604"
@@ -262,6 +283,13 @@ class ErrorCodes(object):
             MobilePhoneIsInvalid = "82683"
             MobilePhoneIsRequired = "82682"
 
+    class OAuth(object):
+        InvalidGrant = "93801"
+        InvalidCredentials = "93802"
+        InvalidScope = "93803"
+        InvalidRequest = "93804"
+        UnsupportedGrantType = "93805"
+
     class PaymentMethod(object):
         CannotForwardPaymentMethodType = "93106"
         PaymentMethodParamsAreRequired = "93101"
@@ -278,15 +306,16 @@ class ErrorCodes(object):
         CannotUpdatePayPalAccountUsingPaymentMethodNonce = "92914"
 
     class PayPalAccount(object):
-        CannotVaultOneTimeUsePayPalAccount = "82902"
         CannotHaveBothAccessTokenAndConsentCode = "82903"
+        CannotVaultOneTimeUsePayPalAccount = "82902"
         ConsentCodeOrAccessTokenIsRequired = "82901"
         CustomerIdIsRequiredForVaulting = "82905"
+        InvalidParamsForPayPalAccountUpdate = "92915"
+        PayPalAccountsAreNotAccepted = "82904"
+        PayPalCommunicationError = "92910"
         PaymentMethodNonceConsumed = "92907"
         PaymentMethodNonceLocked = "92909"
         PaymentMethodNonceUnknown = "92908"
-        PayPalAccountsAreNotAccepted = "82904"
-        PayPalCommunicationError = "92910"
         TokenIsInUse = "92906"
 
     class SettlementBatchSummary(object):
@@ -326,13 +355,20 @@ class ErrorCodes(object):
         InconsistentNumberOfBillingCycles = "91908"
         InconsistentStartDate = "91917"
         InvalidRequestFormat = "91921"
+        MerchantAccountDoesNotSupportInstrumentType = "91930"
         MerchantAccountIdIsInvalid = "91901"
         MismatchCurrencyISOCode = "91923"
         NumberOfBillingCyclesCannotBeBlank = "91912"
         NumberOfBillingCyclesIsTooSmall = "91909"
         NumberOfBillingCyclesMustBeGreaterThanZero = "91907"
         NumberOfBillingCyclesMustBeNumeric = "91906"
+        PaymentMethodNonceCardTypeIsNotAccepted = "91924"
+        PaymentMethodNonceInstrumentTypeDoesNotSupportSubscriptions = "91929"
+        PaymentMethodNonceIsInvalid = "91925"
+        PaymentMethodNonceNotAssociatedWithCustomer = "91926"
+        PaymentMethodNonceUnvaultedCardIsNotAccepted = "91927"
         PaymentMethodTokenCardTypeIsNotAccepted = "91902"
+        PaymentMethodTokenInstrumentTypeDoesNotSupportSubscriptions = "91928"
         PaymentMethodTokenIsInvalid = "91903"
         PaymentMethodTokenNotAssociatedWithCustomer = "91905"
         PlanBillingFrequencyCannotBeUpdated = "91922"
@@ -345,10 +381,6 @@ class ErrorCodes(object):
         TrialDurationFormatIsInvalid = "81907"
         TrialDurationIsRequired = "81908"
         TrialDurationUnitIsInvalid = "81909"
-        PaymentMethodNonceCardTypeIsNotAccepted = "91924"
-        PaymentMethodNonceUnvaultedCardIsNotAccepted = "91927"
-        PaymentMethodNonceIsInvalid = "91925"
-        PaymentMethodNonceNotAssociatedWithCustomer = "91926"
 
         class Modification(object):
             AmountCannotBeBlank = "92003"
@@ -375,6 +407,7 @@ class ErrorCodes(object):
 
     class Transaction(object):
         AmountCannotBeNegative = "81501"
+        AmountDoesNotMatch3DSecureAmount = "91585"
         AmountIsInvalid = AmountFormatIsInvalid = "81503"
         AmountIsRequired = "81502"
         AmountIsTooLarge = "81528"
@@ -396,6 +429,7 @@ class ErrorCodes(object):
         CannotRefundWithSuspendedMerchantAccount = "91538"
         CannotReleaseFromEscrow = "91561"
         CannotSimulateTransactionSettlement = "91575"
+        CannotSubmitForPartialSettlement = "915103"
         CannotSubmitForSettlement = "91507"
         ChannelIsTooLong = "91550"
         ChannelIsTooLong = "91550"
@@ -406,6 +440,7 @@ class ErrorCodes(object):
         CustomerDoesNotHaveCreditCard = "91511"
         CustomerIdIsInvalid = "91510"
         HasAlreadyBeenRefunded = "91512"
+        MerchantAccountDoesNotMatch3DSecureMerchantAccount = "91584"
         MerchantAccountDoesNotSupportMOTO = "91558"
         MerchantAccountDoesNotSupportRefunds = "91547"
         MerchantAccountIdIsInvalid = "91513"
@@ -413,22 +448,29 @@ class ErrorCodes(object):
         MerchantAccountIsSuspended = "91514"
         MerchantAccountNameIsInvalid = "91513" # Deprecated
         OrderIdIsTooLong = "91501"
+        PayPalAuthExpired = "91579"
+        PayPalNotEnabled = "91576"
+        PayPalVaultRecordMissingData = "91583"
         PaymentInstrumentNotSupportedByMerchantAccount = "91577"
+        PaymentInstrumentTypeIsNotAccepted = "915101"
         PaymentMethodConflict = "91515"
         PaymentMethodConflictWithVenmoSDK = "91549"
         PaymentMethodDoesNotBelongToCustomer = "91516"
         PaymentMethodDoesNotBelongToSubscription = "91527"
-        PaymentMethodNonceConsumed = "91564"
-        PaymentMethodNonceLocked = "91566"
         PaymentMethodNonceCardTypeIsNotAccepted = "91567"
+        PaymentMethodNonceConsumed = "91564"
+        PaymentMethodNonceHasNoValidPaymentInstrumentType = "91569"
+        PaymentMethodNonceLocked = "91566"
+        PaymentMethodNonceUnknown = "91565"
         PaymentMethodTokenCardTypeIsNotAccepted = "91517"
         PaymentMethodTokenIsInvalid = "91518"
-        PaymentMethodNonceUnknown = "91565"
-        PayPalNotEnabled = "91576"
-        PayPalAuthExpired = "91579"
         ProcessorAuthorizationCodeCannotBeSet = "91519"
         ProcessorAuthorizationCodeIsInvalid = "81520"
+        ProcessorDoesNotSupportAuths = "915104"
         ProcessorDoesNotSupportCredits = "91546"
+        ProcessorDoesNotSupportPartialSettlement = "915102"
+        ProcessorDoesNotSupportUpdatingOrderId = "915107"
+        ProcessorDoesNotSupportUpdatingDescriptor = "915108"
         ProcessorDoesNotSupportVoiceAuthorizations = "91545"
         PurchaseOrderNumberIsInvalid = "91548"
         PurchaseOrderNumberIsTooLong = "91537"
@@ -449,17 +491,18 @@ class ErrorCodes(object):
         TaxAmountCannotBeNegative = "81534"
         TaxAmountFormatIsInvalid = "81535"
         TaxAmountIsTooLarge = "81536"
+        ThreeDSecureAuthenticationFailed = "81571"
         ThreeDSecureTokenIsInvalid = "91568"
         ThreeDSecureTransactionDataDoesntMatchVerify = "91570"
-        ThreeDSecureAuthenticationFailed = "81571"
         TypeIsInvalid = "91523"
         TypeIsRequired = "91524"
         UnsupportedVoiceAuthorization = "91539"
 
         class Options(object):
-            VaultIsDisabled = "91525"
             SubmitForSettlementIsRequiredForCloning = "91544"
+            SubmitForSettlementIsRequiredForPayPalUnilateral = "91582"
             UseBillingForShippingDisabled = "91572"
+            VaultIsDisabled = "91525"
 
             class PayPal(object):
                 CustomFieldTooLong = "91580"
