@@ -2,9 +2,11 @@ from braintree.exceptions.authentication_error import AuthenticationError
 from braintree.exceptions.authorization_error import AuthorizationError
 from braintree.exceptions.down_for_maintenance_error import DownForMaintenanceError
 from braintree.exceptions.forged_query_string_error import ForgedQueryStringError
+from braintree.exceptions.invalid_challenge_error import InvalidChallengeError
 from braintree.exceptions.invalid_signature_error import InvalidSignatureError
 from braintree.exceptions.not_found_error import NotFoundError
 from braintree.exceptions.server_error import ServerError
 from braintree.exceptions.unexpected_error import UnexpectedError
 from braintree.exceptions.upgrade_required_error import UpgradeRequiredError
 from braintree.exceptions.test_operation_performed_in_production_error import TestOperationPerformedInProductionError
+from braintree.exceptions.configuration_error import ConfigurationError
