@@ -4,6 +4,9 @@ from decimal import Decimal
 from braintree.add_on import AddOn
 from braintree.apple_pay_card import ApplePayCard
 from braintree.coinbase_account import CoinbaseAccount
+from braintree.android_pay_card import AndroidPayCard
+from braintree.amex_express_checkout_card import AmexExpressCheckoutCard
+from braintree.venmo_account import VenmoAccount
 from braintree.disbursement_detail import DisbursementDetail
 from braintree.dispute import Dispute
 from braintree.discount import Discount
@@ -23,12 +26,15 @@ from braintree.transparent_redirect import TransparentRedirect
 from braintree.exceptions.not_found_error import NotFoundError
 from braintree.descriptor import Descriptor
 from braintree.risk_data import RiskData
+from braintree.three_d_secure_info import ThreeDSecureInfo
+from braintree.facilitator_details import FacilitatorDetails
+from braintree.payment_instrument_type import PaymentInstrumentType
 
 class Transaction(Resource):
     """
     A class representing Braintree Transaction objects.
 
-    An example of creating an sale transaction with all available fields::
+    An example of creating a sale transaction with all available fields::
 
         result = Transaction.sale({
             "amount": "100.00",
@@ -75,7 +81,7 @@ class Transaction(Resource):
         print(result.transaction.amount)
         print(result.transaction.order_id)
 
-    For more information on Transactions, see https://developers.braintreepayments.com/python/reference/request/transaction/sale
+    For more information on Transactions, see https://developers.braintreepayments.com/ios+python/reference/request/transaction/sale
 
     """
 
@@ -106,13 +112,14 @@ class Transaction(Resource):
         * braintree.Transaction.GatewayRejectionReason.Fraud
         * braintree.Transaction.GatewayRejectionReason.ThreeDSecure
         """
-        Avs          = "avs"
-        AvsAndCvv    = "avs_and_cvv"
-        Cvv          = "cvv"
-        Duplicate    = "duplicate"
-        Fraud        = "fraud"
-        ThreeDSecure = "three_d_secure"
-        Unrecognized = "unrecognized"
+        ApplicationIncomplete = "application_incomplete"
+        Avs                   = "avs"
+        AvsAndCvv             = "avs_and_cvv"
+        Cvv                   = "cvv"
+        Duplicate             = "duplicate"
+        Fraud                 = "fraud"
+        ThreeDSecure          = "three_d_secure"
+        Unrecognized          = "unrecognized"
 
     class Source(object):
         Api          = "api"
@@ -329,7 +336,7 @@ class Transaction(Resource):
         return Configuration.gateway().transaction.release_from_escrow(transaction_id)
 
     @staticmethod
-    def submit_for_settlement(transaction_id, amount=None):
+    def submit_for_settlement(transaction_id, amount=None, params={}):
         """
         Submits an authorized transaction for settlement.
 
@@ -339,7 +346,7 @@ class Transaction(Resource):
 
         """
 
-        return Configuration.gateway().transaction.submit_for_settlement(transaction_id, amount)
+        return Configuration.gateway().transaction.submit_for_settlement(transaction_id, amount, params)
 
     @staticmethod
     def tr_data_for_credit(tr_data, redirect_url):
@@ -416,6 +423,7 @@ class Transaction(Resource):
             "amount", "customer_id", "device_session_id", "fraud_merchant_id", "merchant_account_id", "order_id", "channel",
             "payment_method_token", "purchase_order_number", "recurring", "shipping_address_id",
             "device_data", "billing_address_id", "payment_method_nonce", "tax_amount",
+            "shared_payment_method_token", "shared_customer_id", "shared_billing_address_id", "shared_shipping_address_id",
             "tax_exempt", "three_d_secure_token", "type", "venmo_sdk_payment_method_code", "service_fee_amount",
             {
                 "credit_card": [
@@ -454,12 +462,22 @@ class Transaction(Resource):
                     {
                         "paypal": [
                             "payee_email",
-                            "custom_field"
+                            "custom_field",
+                            "description",
+                            {"supplementary_data": ["__any_key__"]}
                         ],
                         "three_d_secure": [
                             "required"
                         ],
                     },
+                    {
+                        "amex_rewards": [
+                            "request_id",
+                            "points",
+                            "currency_amount",
+                            "currency_iso_code"
+                        ]
+                    },
                 ]
             },
             {"custom_fields": ["__any_key__"]},
@@ -477,6 +495,23 @@ class Transaction(Resource):
                 }
             ]
 
+    @staticmethod
+    def submit_for_settlement_signature():
+        return ["order_id", {"descriptor": ["name", "phone", "url"]}]
+
+    @staticmethod
+    def submit_for_partial_settlement(transaction_id, amount):
+        """
+        Creates a partial settlement transaction for an authorized transaction
+
+        Requires the transaction id of the authorized transaction and an amount::
+
+            result = braintree.Transaction.submit_for_partial_settlement("my_transaction_id", "20.00")
+
+        """
+
+        return Configuration.gateway().transaction.submit_for_partial_settlement(transaction_id, amount)
+
     def __init__(self, gateway, attributes):
         if "refund_id" in attributes:
             self._refund_id = attributes["refund_id"]
@@ -501,6 +536,12 @@ class Transaction(Resource):
             self.apple_pay_details = ApplePayCard(gateway, attributes.pop("apple_pay"))
         if "coinbase_account" in attributes:
             self.coinbase_details = CoinbaseAccount(gateway, attributes.pop("coinbase_account"))
+        if "android_pay_card" in attributes:
+            self.android_pay_card_details = AndroidPayCard(gateway, attributes.pop("android_pay_card"))
+        if "amex_express_checkout_card" in attributes:
+            self.amex_express_checkout_card_details = AmexExpressCheckoutCard(gateway, attributes.pop("amex_express_checkout_card"))
+        if "venmo_account" in attributes:
+            self.venmo_account_details = VenmoAccount(gateway, attributes.pop("venmo_account"))
         if "customer" in attributes:
             self.customer_details = Customer(gateway, attributes.pop("customer"))
         if "shipping" in attributes:
@@ -526,6 +567,12 @@ class Transaction(Resource):
             self.risk_data = RiskData(attributes["risk_data"])
         else:
             self.risk_data = None
+        if "three_d_secure_info" in attributes and not attributes["three_d_secure_info"] is None:
+            self.three_d_secure_info = ThreeDSecureInfo(attributes["three_d_secure_info"])
+        else:
+            self.three_d_secure_info = None
+        if "facilitator_details" in attributes:
+            self.facilitator_details = FacilitatorDetails(attributes.pop("facilitator_details"))
 
     @property
     def refund_id(self):
