@@ -60,7 +60,8 @@ class Http(object):
     def __http_do(self, http_verb, path, params=None):
         http_strategy = self.config.http_strategy()
         request_body = XmlUtil.xml_from_dict(params) if params else ''
-        full_path = self.config.base_merchant_path() + path
+
+        full_path = path if path.startswith(self.config.base_url()) else (self.config.base_url() + path)
 
         try:
             status, response_body = http_strategy.http_do(http_verb, full_path, self.__headers(), request_body)
@@ -68,7 +69,7 @@ class Http(object):
             if self.config.wrap_http_exceptions:
                 http_strategy.handle_exception(e)
             else:
-                raise e
+                raise
 
         if Http.is_error_status(status):
             Http.raise_exception_from_status(status)
@@ -80,7 +81,7 @@ class Http(object):
 
     def http_do(self, http_verb, path, headers, request_body):
         response = self.__request_function(http_verb)(
-            self.environment.base_url + path,
+            path if path.startswith(self.config.base_url()) else self.config.base_url() + path,
             headers=headers,
             data=request_body,
             verify=self.environment.ssl_certificate,
@@ -110,11 +111,20 @@ class Http(object):
             return requests.delete
 
     def __authorization_header(self):
-        return b"Basic " + encodebytes(
-                    self.config.public_key.encode('ascii') +
-                    b":" +
-                    self.config.private_key.encode('ascii')
-                ).replace(b"\n", b"").strip()
+        if self.config.has_client_credentials():
+            return b"Basic " + encodebytes(
+                        self.config.client_id.encode('ascii') +
+                        b":" +
+                        self.config.client_secret.encode('ascii')
+                    ).replace(b"\n", b"").strip()
+        elif self.config.has_access_token():
+            return b"Bearer " + self.config.access_token.encode('ascii')
+        else:
+            return b"Basic " + encodebytes(
+                        self.config.public_key.encode('ascii') +
+                        b":" +
+                        self.config.private_key.encode('ascii')
+                    ).replace(b"\n", b"").strip()
 
     def __headers(self):
         return {
