@@ -12,37 +12,37 @@ class TestCustomer(unittest.TestCase):
 
     def test_create(self):
         result = Customer.create({
-            "first_name": "Bill",
-            "last_name": "Gates",
-            "company": "Microsoft",
-            "email": "bill@microsoft.com",
+            "first_name": "Joe",
+            "last_name": "Brown",
+            "company": "Fake Company",
+            "email": "joe@email.com",
             "phone": "312.555.1234",
             "fax": "614.555.5678",
-            "website": "www.microsoft.com"
+            "website": "www.email.com"
         })
 
         self.assertTrue(result.is_success)
         customer = result.customer
 
-        self.assertEqual("Bill", customer.first_name)
-        self.assertEqual("Gates", customer.last_name)
-        self.assertEqual("Microsoft", customer.company)
-        self.assertEqual("bill@microsoft.com", customer.email)
+        self.assertEqual("Joe", customer.first_name)
+        self.assertEqual("Brown", customer.last_name)
+        self.assertEqual("Fake Company", customer.company)
+        self.assertEqual("joe@email.com", customer.email)
         self.assertEqual("312.555.1234", customer.phone)
         self.assertEqual("614.555.5678", customer.fax)
-        self.assertEqual("www.microsoft.com", customer.website)
+        self.assertEqual("www.email.com", customer.website)
         self.assertNotEqual(None, customer.id)
         self.assertNotEqual(None, re.search("\A\d{6,7}\Z", customer.id))
 
     def test_create_with_device_session_id_and_fraud_merchant_id(self):
         result = Customer.create({
-            "first_name": "Bill",
-            "last_name": "Gates",
-            "company": "Microsoft",
-            "email": "bill@microsoft.com",
+            "first_name": "Joe",
+            "last_name": "Brown",
+            "company": "Fake Company",
+            "email": "joe@email.com",
             "phone": "312.555.1234",
             "fax": "614.555.5678",
-            "website": "www.microsoft.com",
+            "website": "www.email.com",
             "credit_card": {
                 "number": "4111111111111111",
                 "expiration_date": "05/2010",
@@ -54,27 +54,58 @@ class TestCustomer(unittest.TestCase):
 
         self.assertTrue(result.is_success)
 
-    def test_create_with_unicode(self):
-        result = Customer.create({
-            "first_name": u"Bill<&>",
-            "last_name": u"G\u1F00t\u1F18s",
-            "company": "Microsoft",
-            "email": "bill@microsoft.com",
-            "phone": "312.555.1234",
-            "fax": "614.555.5678",
-            "website": "www.microsoft.com"
+    def test_create_using_access_token(self):
+        gateway = BraintreeGateway(
+            client_id = "client_id$development$integration_client_id",
+            client_secret = "client_secret$development$integration_client_secret",
+            environment = Environment.Development
+        )
+
+        code = TestHelper.create_grant(gateway, {
+            "merchant_public_id": "integration_merchant_id",
+            "scope": "read_write"
+        })
+
+        result = gateway.oauth.create_token_from_code({
+            "code": code
+        })
+
+        gateway = BraintreeGateway(
+            access_token = result.credentials.access_token,
+            environment = Environment.Development
+        )
+
+        result = gateway.customer.create({
+            "first_name": "Joe",
+            "last_name": "Brown"
         })
 
         self.assertTrue(result.is_success)
         customer = result.customer
 
-        self.assertEqual(u"Bill<&>", customer.first_name)
+        self.assertEqual("Joe", customer.first_name)
+
+    def test_create_with_unicode(self):
+        result = Customer.create({
+            "first_name": u"Joe<&>",
+            "last_name": u"G\u1F00t\u1F18s",
+            "company": "Fake Company",
+            "email": "joe@email.com",
+            "phone": "312.555.1234",
+            "fax": "614.555.5678",
+            "website": "www.email.com"
+        })
+
+        self.assertTrue(result.is_success)
+        customer = result.customer
+
+        self.assertEqual(u"Joe<&>", customer.first_name)
         self.assertEqual(u"G\u1f00t\u1F18s", customer.last_name)
-        self.assertEqual("Microsoft", customer.company)
-        self.assertEqual("bill@microsoft.com", customer.email)
+        self.assertEqual("Fake Company", customer.company)
+        self.assertEqual("joe@email.com", customer.email)
         self.assertEqual("312.555.1234", customer.phone)
         self.assertEqual("614.555.5678", customer.fax)
-        self.assertEqual("www.microsoft.com", customer.website)
+        self.assertEqual("www.email.com", customer.website)
         self.assertNotEqual(None, customer.id)
         self.assertNotEqual(None, re.search("\A\d{6,7}\Z", customer.id))
 
@@ -88,6 +119,34 @@ class TestCustomer(unittest.TestCase):
         customer = result.customer
         self.assertNotEqual(None, customer.apple_pay_cards[0])
 
+    def test_create_with_android_pay_proxy_card_nonce(self):
+        result = Customer.create({"payment_method_nonce": Nonces.AndroidPayCardDiscover})
+        self.assertTrue(result.is_success)
+
+        customer = result.customer
+        self.assertIsInstance(customer.android_pay_cards[0], AndroidPayCard)
+
+    def test_create_with_android_pay_network_token_nonce(self):
+        result = Customer.create({"payment_method_nonce": Nonces.AndroidPayCardMasterCard})
+        self.assertTrue(result.is_success)
+
+        customer = result.customer
+        self.assertIsInstance(customer.android_pay_cards[0], AndroidPayCard)
+
+    def test_create_with_amex_express_checkout_card_nonce(self):
+        result = Customer.create({"payment_method_nonce": Nonces.AmexExpressCheckoutCard})
+        self.assertTrue(result.is_success)
+
+        customer = result.customer
+        self.assertIsInstance(customer.amex_express_checkout_cards[0], AmexExpressCheckoutCard)
+
+    def test_create_with_venmo_account_nonce(self):
+        result = Customer.create({"payment_method_nonce": Nonces.VenmoAccount})
+        self.assertTrue(result.is_success)
+
+        customer = result.customer
+        self.assertIsInstance(customer.venmo_accounts[0], VenmoAccount)
+
     def test_create_with_paypal_future_payments_nonce(self):
         result = Customer.create({"payment_method_nonce": Nonces.PayPalFuturePayment})
         self.assertTrue(result.is_success)
@@ -360,46 +419,46 @@ class TestCustomer(unittest.TestCase):
             Customer.find("badid")
             self.assertTrue(False)
         except NotFoundError as e:
-            self.assertEquals("customer with id badid not found", str(e))
+            self.assertEquals("customer with id 'badid' not found", str(e))
 
     def test_update_with_valid_options(self):
         customer = Customer.create({
-            "first_name": "Steve",
-            "last_name": "Jobs",
-            "company": "Apple",
-            "email": "steve@apple.com",
+            "first_name": "Joe",
+            "last_name": "Brown",
+            "company": "Fake Company",
+            "email": "joe@email.com",
             "phone": "312.555.5555",
             "fax": "614.555.5555",
-            "website": "www.apple.com"
+            "website": "www.email.com"
         }).customer
 
         result = Customer.update(customer.id, {
-            "first_name": "Bill",
-            "last_name": "Gates",
-            "company": "Microsoft",
-            "email": "bill@microsoft.com",
+            "first_name": "Joe",
+            "last_name": "Brown",
+            "company": "Fake Company",
+            "email": "joe@email.com",
             "phone": "312.555.1234",
             "fax": "614.555.5678",
-            "website": "www.microsoft.com"
+            "website": "www.email.com"
         })
 
         self.assertTrue(result.is_success)
         customer = result.customer
 
-        self.assertEqual("Bill", customer.first_name)
-        self.assertEqual("Gates", customer.last_name)
-        self.assertEqual("Microsoft", customer.company)
-        self.assertEqual("bill@microsoft.com", customer.email)
+        self.assertEqual("Joe", customer.first_name)
+        self.assertEqual("Brown", customer.last_name)
+        self.assertEqual("Fake Company", customer.company)
+        self.assertEqual("joe@email.com", customer.email)
         self.assertEqual("312.555.1234", customer.phone)
         self.assertEqual("614.555.5678", customer.fax)
-        self.assertEqual("www.microsoft.com", customer.website)
+        self.assertEqual("www.email.com", customer.website)
         self.assertNotEqual(None, customer.id)
         self.assertNotEqual(None, re.search("\A\d{6,7}\Z", customer.id))
 
     def test_update_with_nested_values(self):
         customer = Customer.create({
-            "first_name": "Steve",
-            "last_name": "Jobs",
+            "first_name": "Joe",
+            "last_name": "Brown",
             "credit_card": {
                 "number": "4111111111111111",
                 "expiration_date": "10/10",
@@ -412,8 +471,8 @@ class TestCustomer(unittest.TestCase):
         address = credit_card.billing_address
 
         updated_customer = Customer.update(customer.id, {
-            "first_name": "Bill",
-            "last_name": "Gates",
+            "first_name": "Joe",
+            "last_name": "Brown",
             "credit_card": {
                 "expiration_date": "12/12",
                 "options": {
@@ -434,8 +493,8 @@ class TestCustomer(unittest.TestCase):
         updated_credit_card = CreditCard.find(credit_card.token)
         updated_address = Address.find(customer.id, address.id)
 
-        self.assertEqual("Bill", updated_customer.first_name)
-        self.assertEqual("Gates", updated_customer.last_name)
+        self.assertEqual("Joe", updated_customer.first_name)
+        self.assertEqual("Brown", updated_customer.last_name)
         self.assertEqual("12/2012", updated_credit_card.expiration_date)
         self.assertEqual("44444", updated_address.postal_code)
         self.assertEqual("US", updated_address.country_code_alpha2)
@@ -465,17 +524,17 @@ class TestCustomer(unittest.TestCase):
 
     def test_update_with_invalid_options(self):
         customer = Customer.create({
-            "first_name": "Steve",
-            "last_name": "Jobs",
-            "company": "Apple",
-            "email": "steve@apple.com",
+            "first_name": "Joe",
+            "last_name": "Brown",
+            "company": "Fake Company",
+            "email": "joe@email.com",
             "phone": "312.555.5555",
             "fax": "614.555.5555",
-            "website": "www.apple.com"
+            "website": "www.email.com"
         }).customer
 
         result = Customer.update(customer.id, {
-            "email": "@microsoft.com",
+            "email": "@email.com",
         })
 
         self.assertFalse(result.is_success)
@@ -586,8 +645,8 @@ class TestCustomer(unittest.TestCase):
 
     def test_update_with_nested_values_via_transparent_redirect(self):
         customer = Customer.create({
-            "first_name": "Steve",
-            "last_name": "Jobs",
+            "first_name": "Joe",
+            "last_name": "Brown",
             "credit_card": {
                 "number": "4111111111111111",
                 "expiration_date": "10/10",
@@ -602,8 +661,8 @@ class TestCustomer(unittest.TestCase):
         tr_data = {
             "customer_id": customer.id,
             "customer": {
-                "first_name": "Bill",
-                "last_name": "Gates",
+                "first_name": "Joe",
+                "last_name": "Brown",
                 "credit_card": {
                     "expiration_date": "12/12",
                     "options": {
@@ -627,8 +686,8 @@ class TestCustomer(unittest.TestCase):
         updated_credit_card = CreditCard.find(credit_card.token)
         updated_address = Address.find(customer.id, address.id)
 
-        self.assertEqual("Bill", updated_customer.first_name)
-        self.assertEqual("Gates", updated_customer.last_name)
+        self.assertEqual("Joe", updated_customer.first_name)
+        self.assertEqual("Brown", updated_customer.last_name)
         self.assertEqual("12/2012", updated_credit_card.expiration_date)
         self.assertEqual("44444", updated_address.postal_code)
 
@@ -658,11 +717,12 @@ class TestCustomer(unittest.TestCase):
             "credit_cards": [ {"token": "credit_card"} ],
             "paypal_accounts": [ {"token": "paypal_account"} ],
             "apple_pay_cards": [ {"token": "apple_pay_card"} ],
+            "android_pay_cards": [ {"token": "android_pay_card"} ],
             "europe_bank_accounts": [ {"token": "europe_bank_account"} ],
             "coinbase_accounts": [ {"token": "coinbase_account"} ]
             })
 
         payment_method_tokens = map(lambda payment_method: payment_method.token, customer.payment_methods)
 
-        self.assertEqual(sorted(payment_method_tokens), ["apple_pay_card", "coinbase_account", "credit_card", "europe_bank_account", "paypal_account"])
+        self.assertEqual(sorted(payment_method_tokens), ["android_pay_card", "apple_pay_card", "coinbase_account", "credit_card", "europe_bank_account", "paypal_account"])
 
