@@ -1,4 +1,5 @@
 import time
+from datetime import datetime
 from random import randint
 from tests.test_helper import *
 from braintree.test.credit_card_numbers import CreditCardNumbers
@@ -21,6 +22,7 @@ class TestPaymentMethod(unittest.TestCase):
         found_account = PaymentMethod.find(result.payment_method.token)
         self.assertNotEqual(None, found_account)
         self.assertEquals(found_account.token, created_account.token)
+        self.assertEquals(found_account.customer_id, created_account.customer_id)
 
     def test_create_returns_validation_failures(self):
         http = ClientApiHttp.create()
@@ -109,6 +111,7 @@ class TestPaymentMethod(unittest.TestCase):
         found_credit_card = PaymentMethod.find(result.payment_method.token)
         self.assertNotEqual(None, found_credit_card)
         self.assertEquals(found_credit_card.token, created_credit_card.token)
+        self.assertEquals(found_credit_card.customer_id, created_credit_card.customer_id)
 
     def test_create_with_europe_bank_account_nonce(self):
         config = Configuration.instantiate()
@@ -136,6 +139,7 @@ class TestPaymentMethod(unittest.TestCase):
 
         self.assertTrue(result.is_success)
         self.assertNotEqual(result.payment_method.image_url, None)
+        self.assertEqual(result.payment_method.customer_id, customer_id)
         found_bank_account = PaymentMethod.find(result.payment_method.token)
 
         self.assertNotEqual(found_bank_account, None)
@@ -153,13 +157,113 @@ class TestPaymentMethod(unittest.TestCase):
         apple_pay_card = result.payment_method
         self.assertIsInstance(apple_pay_card, ApplePayCard)
         self.assertNotEqual(apple_pay_card.token, None)
+        self.assertEqual(apple_pay_card.customer_id, customer_id)
         self.assertEqual(ApplePayCard.CardType.MasterCard, apple_pay_card.card_type)
         self.assertEqual("MasterCard 0017", apple_pay_card.payment_instrument_name)
+        self.assertEqual("MasterCard 0017", apple_pay_card.source_description)
         self.assertTrue(apple_pay_card.default)
         self.assertIn("apple_pay", apple_pay_card.image_url)
         self.assertTrue(int(apple_pay_card.expiration_month) > 0)
         self.assertTrue(int(apple_pay_card.expiration_year) > 0)
 
+    def test_create_with_fake_android_pay_proxy_card_nonce(self):
+        customer_id = Customer.create().customer.id
+        result = PaymentMethod.create({
+            "customer_id": customer_id,
+            "payment_method_nonce": Nonces.AndroidPayCardDiscover
+        })
+
+        self.assertTrue(result.is_success)
+        android_pay_card = result.payment_method
+        self.assertIsInstance(android_pay_card, AndroidPayCard)
+        self.assertNotEqual(android_pay_card.token, None)
+        self.assertEqual(android_pay_card.customer_id, customer_id)
+        self.assertEqual(CreditCard.CardType.Discover, android_pay_card.virtual_card_type)
+        self.assertEqual("1117", android_pay_card.virtual_card_last_4)
+        self.assertEqual("Visa 1111", android_pay_card.source_description)
+        self.assertEqual(CreditCard.CardType.Visa, android_pay_card.source_card_type)
+        self.assertEqual("1111", android_pay_card.source_card_last_4)
+        self.assertEqual("1117", android_pay_card.last_4)
+        self.assertEqual(CreditCard.CardType.Discover, android_pay_card.card_type)
+        self.assertTrue(android_pay_card.default)
+        self.assertIn("android_pay", android_pay_card.image_url)
+        self.assertTrue(int(android_pay_card.expiration_month) > 0)
+        self.assertTrue(int(android_pay_card.expiration_year) > 0)
+        self.assertIsInstance(android_pay_card.created_at, datetime)
+        self.assertIsInstance(android_pay_card.updated_at, datetime)
+        self.assertEqual("601111", android_pay_card.bin)
+        self.assertEqual("google_transaction_id", android_pay_card.google_transaction_id)
+
+    def test_create_with_fake_android_pay_network_token_nonce(self):
+        customer_id = Customer.create().customer.id
+        result = PaymentMethod.create({
+            "customer_id": customer_id,
+            "payment_method_nonce": Nonces.AndroidPayCardMasterCard
+        })
+
+        self.assertTrue(result.is_success)
+        android_pay_card = result.payment_method
+        self.assertIsInstance(android_pay_card, AndroidPayCard)
+        self.assertNotEqual(android_pay_card.token, None)
+        self.assertEqual(android_pay_card.customer_id, customer_id)
+        self.assertEqual(CreditCard.CardType.MasterCard, android_pay_card.virtual_card_type)
+        self.assertEqual("4444", android_pay_card.virtual_card_last_4)
+        self.assertEqual("MasterCard 4444", android_pay_card.source_description)
+        self.assertEqual(CreditCard.CardType.MasterCard, android_pay_card.source_card_type)
+        self.assertEqual("4444", android_pay_card.source_card_last_4)
+        self.assertEqual("4444", android_pay_card.last_4)
+        self.assertEqual(CreditCard.CardType.MasterCard, android_pay_card.card_type)
+        self.assertTrue(android_pay_card.default)
+        self.assertIn("android_pay", android_pay_card.image_url)
+        self.assertTrue(int(android_pay_card.expiration_month) > 0)
+        self.assertTrue(int(android_pay_card.expiration_year) > 0)
+        self.assertIsInstance(android_pay_card.created_at, datetime)
+        self.assertIsInstance(android_pay_card.updated_at, datetime)
+        self.assertEqual("555555", android_pay_card.bin)
+        self.assertEqual("google_transaction_id", android_pay_card.google_transaction_id)
+
+    def test_create_with_fake_amex_express_checkout_card_nonce(self):
+        customer_id = Customer.create().customer.id
+        result = PaymentMethod.create({
+            "customer_id": customer_id,
+            "payment_method_nonce": Nonces.AmexExpressCheckoutCard
+        })
+
+        self.assertTrue(result.is_success)
+        amex_express_checkout_card = result.payment_method
+        self.assertIsInstance(amex_express_checkout_card, AmexExpressCheckoutCard)
+        self.assertNotEqual(amex_express_checkout_card.token, None)
+        self.assertTrue(amex_express_checkout_card.default)
+        self.assertEqual(amex_express_checkout_card.card_type, "American Express")
+        self.assertRegexpMatches(amex_express_checkout_card.bin, r"\A\d{6}\Z")
+        self.assertRegexpMatches(amex_express_checkout_card.expiration_month, r"\A\d{2}\Z")
+        self.assertRegexpMatches(amex_express_checkout_card.expiration_year, r"\A\d{4}\Z")
+        self.assertRegexpMatches(amex_express_checkout_card.card_member_number, r"\A\d{4}\Z")
+        self.assertRegexpMatches(amex_express_checkout_card.card_member_expiry_date, r"\A\d{2}/\d{2}\Z")
+        self.assertRegexpMatches(amex_express_checkout_card.source_description, r"\AAmEx \d{4}\Z")
+        self.assertRegexpMatches(amex_express_checkout_card.image_url, r"\.png")
+        self.assertEqual(amex_express_checkout_card.customer_id, customer_id)
+
+    def test_create_with_venmo_account_nonce(self):
+        customer_id = Customer.create().customer.id
+        result = PaymentMethod.create({
+            "customer_id": customer_id,
+            "payment_method_nonce": Nonces.VenmoAccount,
+        })
+
+        self.assertTrue(result.is_success)
+        venmo_account = result.payment_method
+        self.assertIsInstance(venmo_account, VenmoAccount)
+
+        self.assertTrue(venmo_account.default)
+        self.assertIsNotNone(venmo_account.token)
+        self.assertEqual(venmo_account.username, "venmojoe")
+        self.assertEqual(venmo_account.venmo_user_id, "Venmo-Joe-1")
+        self.assertEqual(venmo_account.source_description, "Venmo Account: venmojoe")
+        self.assertRegexpMatches(venmo_account.image_url, r"\.png")
+        self.assertEqual(venmo_account.customer_id, customer_id)
+
+
     def test_create_with_abstract_payment_method_nonce(self):
         customer_id = Customer.create().customer.id
         result = PaymentMethod.create({
@@ -171,6 +275,7 @@ class TestPaymentMethod(unittest.TestCase):
         payment_method = result.payment_method
         self.assertNotEqual(None, payment_method)
         self.assertNotEqual(None, payment_method.token)
+        self.assertEqual(customer_id, payment_method.customer_id)
 
     def test_create_respects_verify_card_and_verification_merchant_account_id_when_outside_nonce(self):
         config = Configuration.instantiate()
@@ -265,11 +370,11 @@ class TestPaymentMethod(unittest.TestCase):
         })
 
         self.assertTrue(payment_method_result.is_success)
-        self.assertTrue(type(payment_method_result.payment_method) is CreditCard)
+        self.assertTrue(isinstance(payment_method_result.payment_method, CreditCard))
         token = payment_method_result.payment_method.token
 
         found_credit_card = CreditCard.find(token)
-        self.assertFalse(found_credit_card == None)
+        self.assertFalse(found_credit_card is None)
         self.assertTrue(found_credit_card.billing_address.first_name == "Bobby")
         self.assertTrue(found_credit_card.billing_address.last_name == "Tables")
 
@@ -293,11 +398,11 @@ class TestPaymentMethod(unittest.TestCase):
         })
 
         self.assertTrue(result.is_success)
-        self.assertTrue(type(result.payment_method) is CreditCard)
+        self.assertTrue(isinstance(result.payment_method, CreditCard))
         token = result.payment_method.token
 
         found_credit_card = CreditCard.find(token)
-        self.assertFalse(found_credit_card == None)
+        self.assertFalse(found_credit_card is None)
         self.assertTrue(found_credit_card.billing_address.street_address == "123 Abc Way")
 
     def test_create_overrides_the_billing_address_in_the_nonce(self):
@@ -323,11 +428,11 @@ class TestPaymentMethod(unittest.TestCase):
         })
 
         self.assertTrue(result.is_success)
-        self.assertTrue(type(result.payment_method) is CreditCard)
+        self.assertTrue(isinstance(result.payment_method, CreditCard))
         token = result.payment_method.token
 
         found_credit_card = CreditCard.find(token)
-        self.assertFalse(found_credit_card == None)
+        self.assertFalse(found_credit_card is None)
         self.assertTrue(found_credit_card.billing_address.street_address == "123 Abc Way")
 
     def test_create_does_not_override_the_billing_address_for_a_valuted_credit_card(self):
@@ -355,11 +460,11 @@ class TestPaymentMethod(unittest.TestCase):
         })
 
         self.assertTrue(result.is_success)
-        self.assertTrue(type(result.payment_method) is CreditCard)
+        self.assertTrue(isinstance(result.payment_method, CreditCard))
         token = result.payment_method.token
 
         found_credit_card = CreditCard.find(token)
-        self.assertFalse(found_credit_card == None)
+        self.assertFalse(found_credit_card is None)
         self.assertTrue(found_credit_card.billing_address.street_address == "456 Xyz Way")
 
     def test_create_does_not_return_an_error_if_credit_card_options_are_present_for_paypal_nonce(self):
@@ -394,12 +499,12 @@ class TestPaymentMethod(unittest.TestCase):
         })
 
         self.assertTrue(result.is_success)
-        self.assertTrue(type(result.payment_method) is PayPalAccount)
-        self.assertFalse(result.payment_method.image_url == None)
+        self.assertTrue(isinstance(result.payment_method, PayPalAccount))
+        self.assertFalse(result.payment_method.image_url is None)
         token = result.payment_method.token
 
         found_paypal_account = PayPalAccount.find(token)
-        self.assertFalse(found_paypal_account == None)
+        self.assertFalse(found_paypal_account is None)
 
     def test_create_for_paypal_ignores_passed_billing_address_params(self):
         nonce = TestHelper.nonce_for_paypal_account({
@@ -415,12 +520,12 @@ class TestPaymentMethod(unittest.TestCase):
         })
 
         self.assertTrue(result.is_success)
-        self.assertTrue(type(result.payment_method) is PayPalAccount)
-        self.assertFalse(result.payment_method.image_url == None)
+        self.assertTrue(isinstance(result.payment_method, PayPalAccount))
+        self.assertFalse(result.payment_method.image_url is None)
         token = result.payment_method.token
 
         found_paypal_account = PayPalAccount.find(token)
-        self.assertFalse(found_paypal_account == None)
+        self.assertFalse(found_paypal_account is None)
 
     def test_find_returns_an_abstract_payment_method(self):
         customer_id = Customer.create().customer.id
@@ -464,6 +569,21 @@ class TestPaymentMethod(unittest.TestCase):
         self.assertEquals(found_credit_card.__class__, CreditCard)
         self.assertEquals(found_credit_card.bin, "411111")
 
+    def test_find_returns_an_android_pay_card(self):
+        customer = Customer.create().customer
+        result = PaymentMethod.create({
+            "customer_id": customer.id,
+            "payment_method_nonce": Nonces.AndroidPayCard
+        })
+
+        self.assertTrue(result.is_success)
+        android_pay_card = result.payment_method
+
+        found_android_pay_card = PaymentMethod.find(android_pay_card.token)
+        self.assertNotEqual(None, found_android_pay_card)
+        self.assertEquals(found_android_pay_card.__class__, AndroidPayCard)
+        self.assertEqual(android_pay_card.token, found_android_pay_card.token)
+
     def test_delete_deletes_a_credit_card(self):
         customer = Customer.create().customer
         result = CreditCard.create({
@@ -531,7 +651,7 @@ class TestPaymentMethod(unittest.TestCase):
         self.assertTrue(update_result.is_success)
         updated_credit_card = update_result.payment_method
         self.assertTrue(updated_credit_card.billing_address.region == "IL")
-        self.assertTrue(updated_credit_card.billing_address.street_address == None)
+        self.assertTrue(updated_credit_card.billing_address.street_address is None)
         self.assertFalse(updated_credit_card.billing_address.id == credit_card_result.credit_card.billing_address.id)
 
     def test_update_updates_the_billing_address_if_option_is_specified(self):
@@ -625,7 +745,7 @@ class TestPaymentMethod(unittest.TestCase):
         })
         self.assertFalse(update_result.is_success)
         self.assertTrue(update_result.credit_card_verification.status == CreditCardVerification.Status.ProcessorDeclined)
-        self.assertTrue(update_result.credit_card_verification.gateway_rejection_reason == None)
+        self.assertTrue(update_result.credit_card_verification.gateway_rejection_reason is None)
 
     def test_update_can_update_the_billing_address(self):
         customer_id = Customer.create().customer.id
@@ -791,6 +911,68 @@ class TestPaymentMethod(unittest.TestCase):
         self.assertTrue(updated_result.is_success == False)
         self.assertTrue(updated_result.errors.deep_errors[0].code == "92906")
 
+    def test_payment_method_grant_raises_on_non_existent_tokens(self):
+        granting_gateway, credit_card = TestHelper.create_payment_method_grant_fixtures()
+        self.assertRaises(NotFoundError, granting_gateway.payment_method.grant, "non-existant-token", False)
+
+    def test_payment_method_grant_returns_one_time_nonce(self):
+        """
+        Payment method grant returns a nonce that is transactable by a partner merchant exactly once
+        """
+        granting_gateway, credit_card = TestHelper.create_payment_method_grant_fixtures()
+        grant_result = granting_gateway.payment_method.grant(credit_card.token, False)
+        self.assertTrue(grant_result.is_success)
+
+        result = Transaction.sale({
+            "payment_method_nonce": grant_result.payment_method_nonce.nonce,
+            "amount": TransactionAmounts.Authorize
+        })
+        self.assertTrue(result.is_success)
+        result = Transaction.sale({
+            "payment_method_nonce": grant_result.payment_method_nonce.nonce,
+            "amount": TransactionAmounts.Authorize
+        })
+        self.assertFalse(result.is_success)
+
+    def test_payment_method_grant_returns_a_nonce_that_is_not_vaultable(self):
+        granting_gateway, credit_card = TestHelper.create_payment_method_grant_fixtures()
+        grant_result = granting_gateway.payment_method.grant(credit_card.token, False)
+        customer_id = Customer.create().customer.id
+
+        result = PaymentMethod.create({
+            "customer_id": customer_id,
+            "payment_method_nonce": grant_result.payment_method_nonce.nonce
+        })
+        self.assertFalse(result.is_success)
+
+    def test_payment_method_grant_returns_a_nonce_that_is_vaultable(self):
+        granting_gateway, credit_card = TestHelper.create_payment_method_grant_fixtures()
+        grant_result = granting_gateway.payment_method.grant(credit_card.token, True)
+        customer_id = Customer.create().customer.id
+
+        result = PaymentMethod.create({
+            "customer_id": customer_id,
+            "payment_method_nonce": grant_result.payment_method_nonce.nonce
+        })
+        self.assertTrue(result.is_success)
+
+    def test_payment_method_revoke_renders_a_granted_nonce_unusable(self):
+        granting_gateway, credit_card = TestHelper.create_payment_method_grant_fixtures()
+        grant_result = granting_gateway.payment_method.grant(credit_card.token, False)
+
+        revoke_result = granting_gateway.payment_method.revoke(credit_card.token)
+        self.assertTrue(revoke_result.is_success)
+
+        result = Transaction.sale({
+            "payment_method_nonce": grant_result.payment_method_nonce.nonce,
+            "amount": TransactionAmounts.Authorize
+        })
+        self.assertFalse(result.is_success)
+
+    def test_payment_method_revoke_raises_on_non_existent_tokens(self):
+        granting_gateway, credit_card = TestHelper.create_payment_method_grant_fixtures()
+        self.assertRaises(NotFoundError, granting_gateway.payment_method.revoke, "non-existant-token")
+
 class CreditCardForwardingTest(unittest.TestCase):
     def setUp(self):
         braintree.Configuration.configure(
