@@ -94,8 +94,16 @@ class TestWebhooks(unittest.TestCase):
         self.assertTrue((datetime.utcnow() - notification.timestamp).seconds < 10)
 
     def test_verify_returns_a_correct_challenge_response(self):
-        response = WebhookNotification.verify("verification_token")
-        self.assertEquals("integration_public_key|c9f15b74b0d98635cd182c51e2703cffa83388c3", response)
+        response = WebhookNotification.verify("20f9f8ed05f77439fe955c977e4c8a53")
+        self.assertEquals("integration_public_key|d9b899556c966b3f06945ec21311865d35df3ce4", response)
+
+    def test_verify_raises_when_challenge_is_invalid(self):
+        try:
+            WebhookNotification.verify("bad challenge")
+        except InvalidChallengeError as e:
+            self.assertEquals("challenge contains non-hex characters", str(e))
+        else:
+            self.assertFalse("raises exception")
 
     def test_builds_notification_for_approved_sub_merchant_account(self):
         sample_notification = WebhookTesting.sample_notification(
@@ -181,6 +189,8 @@ class TestWebhooks(unittest.TestCase):
         self.assertEquals(WebhookNotification.Kind.DisputeOpened, notification.kind)
         self.assertEquals("my_id", notification.dispute.id)
         self.assertEquals(Dispute.Status.Open, notification.dispute.status)
+        self.assertEquals(Dispute.Kind.Chargeback, notification.dispute.kind)
+        self.assertEquals(notification.dispute.date_opened, date(2014, 3, 28))
 
     def test_builds_notification_for_dispute_lost(self):
         sample_notification = WebhookTesting.sample_notification(
@@ -193,6 +203,8 @@ class TestWebhooks(unittest.TestCase):
         self.assertEquals(WebhookNotification.Kind.DisputeLost, notification.kind)
         self.assertEquals("my_id", notification.dispute.id)
         self.assertEquals(Dispute.Status.Lost, notification.dispute.status)
+        self.assertEquals(Dispute.Kind.Chargeback, notification.dispute.kind)
+        self.assertEquals(notification.dispute.date_opened, date(2014, 3, 28))
 
     def test_builds_notification_for_dispute_won(self):
         sample_notification = WebhookTesting.sample_notification(
@@ -205,6 +217,9 @@ class TestWebhooks(unittest.TestCase):
         self.assertEquals(WebhookNotification.Kind.DisputeWon, notification.kind)
         self.assertEquals("my_id", notification.dispute.id)
         self.assertEquals(Dispute.Status.Won, notification.dispute.status)
+        self.assertEquals(Dispute.Kind.Chargeback, notification.dispute.kind)
+        self.assertEquals(notification.dispute.date_opened, date(2014, 3, 28))
+        self.assertEquals(notification.dispute.date_won, date(2014, 9, 1))
 
     def test_builds_notification_for_partner_merchant_connected(self):
         sample_notification = WebhookTesting.sample_notification(
@@ -245,3 +260,30 @@ class TestWebhooks(unittest.TestCase):
         self.assertEquals(WebhookNotification.Kind.PartnerMerchantDeclined, notification.kind)
         self.assertEquals("abc123", notification.partner_merchant.partner_merchant_id)
         self.assertTrue((datetime.utcnow() - notification.timestamp).seconds < 10)
+
+    def test_builds_notification_for_subscription_charged_successfully(self):
+        sample_notification = WebhookTesting.sample_notification(
+            WebhookNotification.Kind.SubscriptionChargedSuccessfully,
+            "my_id"
+        )
+
+        notification = WebhookNotification.parse(sample_notification['bt_signature'], sample_notification['bt_payload'])
+
+        self.assertEquals(WebhookNotification.Kind.SubscriptionChargedSuccessfully, notification.kind)
+        self.assertEquals("my_id", notification.subscription.id)
+        self.assertTrue(len(notification.subscription.transactions) == 1)
+
+        transaction = notification.subscription.transactions.pop()
+
+        self.assertEquals("submitted_for_settlement", transaction.status)
+        self.assertEquals(Decimal("49.99"), transaction.amount)
+
+    def test_builds_notification_for_check(self):
+        sample_notification = WebhookTesting.sample_notification(
+            WebhookNotification.Kind.Check,
+            ""
+        )
+
+        notification = WebhookNotification.parse(sample_notification['bt_signature'], sample_notification['bt_payload'])
+
+        self.assertEquals(WebhookNotification.Kind.Check, notification.kind)
